==> internetradioplayer_0.0.7.tar.gz: internetradioplayer-0.0.7/internetradioplayer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>FilterListByDialog</name>
    <message>
        <location filename="filterlistbydialog.ui" line="14"/>
        <source>Filter List By</source>
        <translation>Filtra la lista per</translation>
    </message>
    <message>
        <location filename="filterlistbydialog.ui" line="42"/>
        <source>Ok</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Internet Radio Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="39"/>
        <source>Playing: </source>
        <translation>In esecuzione: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Genre: </source>
        <translation>Genere: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>Location:</source>
        <translation>Posizione: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <source>Bitrate:</source>
        <translation>Bitrate: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="67"/>
        <source>Audio Codec: </source>
        <translation>Codec Audio: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="218"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600; text-decoration: underline;&quot;&gt;Internet Radio Player&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt; font-weight:600; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="258"/>
        <source>Artist:</source>
        <translation>Artista: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.ui" line="524"/>
        <source>Lyrics</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="301"/>
        <source>Title:</source>
        <translation>Titolo: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="478"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Playing now</source>
        <translation>In esecuzione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="537"/>
        <source>Stations</source>
        <translation>Stazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="544"/>
        <source>Cronology</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="563"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <location filename="mainwindow.cpp" line="257"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="577"/>
        <source>About Qt</source>
        <translation>Informazioni su Qt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="582"/>
        <source>ToggleFullscreen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="585"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="593"/>
        <source>ClearList</source>
        <translation>Azzera Lista</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="598"/>
        <source>RestoreDefaultList</source>
        <translation>Ripristina Lista di default</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>FilterListByGenre</source>
        <translation>Filtra lista per genere</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="608"/>
        <source>FilterListByCountry</source>
        <translation>Filtra lista per paese</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <source>DoNotFilter</source>
        <translation>Nessun filtro</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>&lt;b&gt;Playing:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;In esecuzione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="101"/>
        <source>&lt;b&gt;Genre:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Genere:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="109"/>
        <source>&lt;b&gt;Bitrate:&lt;/b&gt; %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="117"/>
        <source>&lt;b&gt;Location:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Posizione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="125"/>
        <source>&lt;b&gt;Audio codec:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Codec audio:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="175"/>
        <source>No lyric found</source>
        <translation>Nessun testo trovato</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="194"/>
        <source>Loading lyrics...</source>
        <translation>Sto cercando il testo...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="258"/>
        <source>&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <oldsource>&lt;h2&gt;Internet Radio Player 0.0.6&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</oldsource>
        <translation>&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="269"/>
        <location filename="mainwindow.cpp" line="271"/>
        <location filename="mainwindow.cpp" line="273"/>
        <location filename="mainwindow.cpp" line="275"/>
        <source>New Station</source>
        <translation>Nuova stazione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="269"/>
        <location filename="mainwindow.cpp" line="297"/>
        <source>Insert Name: </source>
        <translation>Inserisci nome:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="271"/>
        <location filename="mainwindow.cpp" line="299"/>
        <source>Insert Url: </source>
        <translation>Inserisci Indirizzo:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="273"/>
        <location filename="mainwindow.cpp" line="301"/>
        <source>Insert Genre: </source>
        <translation>Inserisci Genere:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="275"/>
        <location filename="mainwindow.cpp" line="303"/>
        <source>Insert Country: </source>
        <translation>Inserisci il Paese:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="297"/>
        <location filename="mainwindow.cpp" line="299"/>
        <location filename="mainwindow.cpp" line="301"/>
        <location filename="mainwindow.cpp" line="303"/>
        <source>Edit Station</source>
        <translation>Modifica la stazione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="321"/>
        <location filename="mainwindow.cpp" line="443"/>
        <location filename="mainwindow.cpp" line="459"/>
        <source>Internet Radio Widget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="322"/>
        <source>Do you really want to delete the chosen station?</source>
        <translation>Vuoi veramente cancellare la stazione evidenziata?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="444"/>
        <source>This will clear your stations list.&lt;p&gt;Do you really want to continue?</source>
        <translation>Questo azzererà la tua lista stazioni.&lt;p&gt;Vuoi veramente continuare?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="460"/>
        <source>This will clear your stations list and restore default one.&lt;p&gt;Do you really want to continue?</source>
        <translation>Questo azzererà la tua lista stazioni e ripristinerà quella di default-.&lt;p&gt;Vuoi veramente continuare?</translation>
    </message>
</context>
</TS>

==> internetradioplayer_0.1.0.tar.gz: internetradioplayer-0.1.0/internetradioplayer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>FilterListByDialog</name>
    <message>
        <location filename="filterlistbydialog.ui" line="14"/>
        <source>Filter List By</source>
        <translation>Filtra la lista per</translation>
    </message>
    <message>
        <location filename="filterlistbydialog.ui" line="42"/>
        <source>Ok</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LyricsWebView</name>
    <message>
        <location filename="lyricswebview.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="lyricswebview.ui" line="28"/>
        <source>about:blank</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Internet Radio Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="39"/>
        <source>Playing: </source>
        <translation>In esecuzione: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Genre: </source>
        <translation>Genere: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>Location:</source>
        <translation>Posizione: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <source>Bitrate:</source>
        <translation>Bitrate: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="67"/>
        <source>Audio Codec: </source>
        <translation>Codec Audio: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="218"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600; text-decoration: underline;&quot;&gt;Internet Radio Player&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt; font-weight:600; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="258"/>
        <source>Artist:</source>
        <translation>Artista: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.ui" line="540"/>
        <source>Lyrics</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="301"/>
        <source>Title:</source>
        <translation>Titolo: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="339"/>
        <source>lyrics.com</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="524"/>
        <source>Playing now</source>
        <translation>In esecuzione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="553"/>
        <source>Stations</source>
        <translation>Stazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>Cronology</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="579"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="589"/>
        <location filename="mainwindow.cpp" line="263"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="594"/>
        <source>About Qt</source>
        <translation>Informazioni su Qt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="599"/>
        <source>ToggleFullscreen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="602"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="610"/>
        <source>ClearList</source>
        <translation>Azzera Lista</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="615"/>
        <source>RestoreDefaultList</source>
        <translation>Ripristina Lista di default</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="620"/>
        <source>FilterListByGenre</source>
        <translation>Filtra lista per genere</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="625"/>
        <source>FilterListByCountry</source>
        <translation>Filtra lista per paese</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="630"/>
        <source>DoNotFilter</source>
        <translation>Nessun filtro</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="635"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="84"/>
        <source>&lt;b&gt;Playing:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;In esecuzione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="107"/>
        <source>&lt;b&gt;Genre:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Genere:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="115"/>
        <source>&lt;b&gt;Bitrate:&lt;/b&gt; %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="123"/>
        <source>&lt;b&gt;Location:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Posizione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="131"/>
        <source>&lt;b&gt;Audio codec:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Codec audio:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="181"/>
        <source>No lyric found</source>
        <translation>Nessun testo trovato</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="200"/>
        <source>Loading lyrics...</source>
        <translation>Sto cercando il testo...</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <oldsource>&lt;h2&gt;Internet Radio Player 0.0.6&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</oldsource>
        <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Internet Radio Player 0.0.8&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt; {2&gt;?} {0.0.8&lt;?} {2&gt;?} {88@?} {88@?}</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="264"/>
        <source>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <translation>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="275"/>
        <location filename="mainwindow.cpp" line="277"/>
        <location filename="mainwindow.cpp" line="279"/>
        <location filename="mainwindow.cpp" line="281"/>
        <source>New Station</source>
        <translation>Nuova stazione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="275"/>
        <location filename="mainwindow.cpp" line="303"/>
        <source>Insert Name: </source>
        <translation>Inserisci nome:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="277"/>
        <location filename="mainwindow.cpp" line="305"/>
        <source>Insert Url: </source>
        <translation>Inserisci Indirizzo:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="279"/>
        <location filename="mainwindow.cpp" line="307"/>
        <source>Insert Genre: </source>
        <translation>Inserisci Genere:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="281"/>
        <location filename="mainwindow.cpp" line="309"/>
        <source>Insert Country: </source>
        <translation>Inserisci il Paese:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="303"/>
        <location filename="mainwindow.cpp" line="305"/>
        <location filename="mainwindow.cpp" line="307"/>
        <location filename="mainwindow.cpp" line="309"/>
        <source>Edit Station</source>
        <translation>Modifica la stazione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <location filename="mainwindow.cpp" line="449"/>
        <location filename="mainwindow.cpp" line="465"/>
        <source>Internet Radio Widget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="328"/>
        <source>Do you really want to delete the chosen station?</source>
        <translation>Vuoi veramente cancellare la stazione evidenziata?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="450"/>
        <source>This will clear your stations list.&lt;p&gt;Do you really want to continue?</source>
        <translation>Questo azzererà la tua lista stazioni.&lt;p&gt;Vuoi veramente continuare?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="466"/>
        <source>This will clear your stations list and restore default one.&lt;p&gt;Do you really want to continue?</source>
        <translation>Questo azzererà la tua lista stazioni e ripristinerà quella di default-.&lt;p&gt;Vuoi veramente continuare?</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="53"/>
        <source>Application Icon</source>
        <translation>Icona App</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="174"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
</context>
</TS>
